@@ -65,11 +65,11 @@ class BotStats(utils.Cog):
         embed.set_footer(f"{self.bot.user} - VoxelBotUtils v{__version__}", icon_url=self.bot.user.avatar_url)
         embed.add_field("Creator", f"{creator!s}\n{creator_id}")
         embed.add_field("Library", f"Discord.py {discord.__version__}")
-        if self.bot.shard_count != len(self.bot.shard_ids):
-            embed.add_field("Approximate Guild Count", int((len(self.bot.guilds) / len(self.bot.shard_ids)) * self.bot.shard_count))
+        if self.bot.shard_count != len((self.bot.shard_ids or [0])):
+            embed.add_field("Approximate Guild Count", int((len(self.bot.guilds) / len(self.bot.shard_ids or [0])) * self.bot.shard_count))
         else:
             embed.add_field("Guild Count", len(self.bot.guilds))
-        embed.add_field("Shard Count", self.bot.shard_count)
+        embed.add_field("Shard Count", self.bot.shard_count or 1)
         embed.add_field("Average WS Latency", f"{(self.bot.latency * 1000):.2f}ms")
         embed.add_field("Coroutines", f"{len([i for i in asyncio.Task.all_tasks() if not i.done()])} running, {len(asyncio.Task.all_tasks())} total.")
 
