@@ -12,11 +12,15 @@ class ConnectEvent(utils.Cog):
         Send a webhook to the bot specified event webhook url.
         """
 
-        event_webhook = self.bot.get_event_webhook(event_name)
+        event_webhook: discord.Webhook = self.bot.get_event_webhook(event_name)
         if not event_webhook:
             return False
         try:
-            await event_webhook.send(text, username=username)
+            avatar_url = str(self.bot.user.avatar_url)
+        except Exception:
+            avatar_url = None
+        try:
+            await event_webhook.send(discord.utils.escape_mentions(text), username=username, avatar_url=avatar_url)
         except discord.HTTPException as e:
             self.logger.error(f"Failed to send webhook for event {event_name} - {e}")
             return False
@@ -86,11 +90,37 @@ class ConnectEvent(utils.Cog):
 
         await self.send_webhook(
             "bot_disconnect",
-            f"Bot disconnect event just pinged for instance with shards `{self.bot.shard_ids}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Bot disconnect event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - {dt.utcnow().strftime('%X.%f')}",
             f"{self.bot.user.name} - Disconnect",
             "Sent webhook for on_disconnect event",
         )
 
+    @utils.Cog.listener()
+    async def on_shard_resumed(self, shard_id:int):
+        """
+        Ping a given webhook when the shard ID is resumed.
+        """
+
+        await self.send_webhook(
+            "shard_connect",
+            f"Shard resumed event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
+            f"{self.bot.user.name} - Shard Resumed",
+            f"Sent webhook for on_shard_resumed event in shard `{shard_id}`",
+        )
+
+    @utils.Cog.listener()
+    async def on_resumed(self):
+        """
+        Ping a given webhook when the bot is resumed.
+        """
+
+        await self.send_webhook(
+            "bot_connect",
+            f"Bot resumed event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - {dt.utcnow().strftime('%X.%f')}",
+            f"{self.bot.user.name} - Resumed",
+            "Sent webhook for on_resumed event",
+        )
+
     @utils.Cog.listener()
     async def on_guild_join(self, guild:discord.Guild):
         """
@@ -110,12 +140,30 @@ class ConnectEvent(utils.Cog):
         Ping a given webhook when the bot is removed from a guild.
         """
 
-        await self.send_webhook(
-            "guild_remove",
-            f"Removed from guild - ``{guild.name}`` (`{guild.member_count}` members)",
-            f"{self.bot.user.name} - Guild Remove",
-            "Sent webhook for on_guild_remove event",
-        )
+        if guild.me:
+            try:
+                member_count = guild.member_count
+                text = f"Removed from guild - ``{guild.name}`` (`{member_count}` members; `{utils.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)",
+            except Exception:
+                text = f"Removed from guild - ``{guild.name}`` (`{utils.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)",
+            await self.send_webhook(
+                "guild_remove",
+                text,
+                f"{self.bot.user.name} - Guild Remove",
+                "Sent webhook for on_guild_remove event",
+            )
+        else:
+            try:
+                member_count = guild.member_count
+                text = f"Removed from guild - ``{guild.name}`` (`{member_count}` members)",
+            except Exception:
+                text = f"Removed from guild - ``{guild.name}``",
+            await self.send_webhook(
+                "guild_remove",
+                text,
+                f"{self.bot.user.name} - Guild Remove",
+                "Sent webhook for on_guild_remove event",
+            )
 
 
 def setup(bot:utils.Bot):
