@@ -24,6 +24,10 @@ class ErrorHandler(utils.Cog):
             (commands.UnexpectedQuoteError, commands.InvalidEndOfQuotedStringError, commands.ExpectedClosingQuoteError),
             lambda ctx, error: "The quotes in your message have been done incorrectly."
         ),
+        (
+            utils.checks.cooldown.NoRaiseCommandOnCooldown,
+            lambda ctx, error: None
+        ),
         (
             commands.CommandOnCooldown,
             lambda ctx, error: f"You can't use this command again for another {utils.TimeValue(error.retry_after).clean_spaced}."
@@ -214,7 +218,7 @@ class ErrorHandler(utils.Cog):
 
         # Set up some errors that the owners are able to bypass
         owner_reinvoke_errors = (
-            # commands.MissingRole, commands.MissingAnyRole, commands.MissingPermissions,
+            commands.MissingRole, commands.MissingAnyRole, commands.MissingPermissions,
             commands.CommandOnCooldown, commands.DisabledCommand,
         )
         if isinstance(error, owner_reinvoke_errors) and ctx.original_author_id in self.bot.owner_ids:
@@ -263,15 +267,16 @@ class ErrorHandler(utils.Cog):
                 await owner.send(error_text, file=discord.File(file_handle, filename="error_log.py"))
 
         # Ping to the webook
-        event_webhook = self.bot.get_event_webhook("unhandled_error")
+        event_webhook: discord.Webhook = self.bot.get_event_webhook("unhandled_error")
+        try:
+            avatar_url = str(self.bot.user.avatar_url)
+        except Exception:
+            avatar_url = None
         if event_webhook:
             file_handle.seek(0)
             try:
-                await event_webhook.send(
-                    error_text,
-                    file=discord.File(file_handle, filename="error_log.py"),
-                    username=f"{self.bot.user.name} - Error"
-                )
+                file = discord.File(file_handle, filename="error_log.py")
+                await event_webhook.send(error_text, file=file, username=f"{self.bot.user.name} - Error", avatar_url=avatar_url)
             except discord.HTTPException as e:
                 self.logger.error(f"Failed to send webhook for event unhandled_error - {e}")
 
