@@ -6,6 +6,7 @@ import os
 import json
 import textwrap
 import traceback
+import time
 import typing
 import inspect
 
@@ -28,10 +29,15 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         Shows you the source for a given command.
         """
 
+        # Get command
         command = self.bot.get_command(command_name)
         if command is None:
             return await ctx.send(f"I couldn't find a command named `{command_name}`.", allowed_mentions=discord.AllowedMentions.none())
+
+        # Get its source
         data = textwrap.dedent(inspect.getsource(command.callback))
+
+        # Work out our pages
         lines = data.strip().split("\n")
         current, last = "", ""
         pages = []
@@ -44,63 +50,8 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         if last:
             pages.append(f"```py\n{last}\n```")
 
-        message = await ctx.send(pages[0])
-
-        # List of valid emojis the user can react with
-        valid_emoji = [
-            "\N{BLACK LEFT-POINTING TRIANGLE}",
-            "\N{BLACK RIGHT-POINTING TRIANGLE}",
-            "\N{WHITE HEAVY CHECK MARK}"
-        ]
-
-        # Reacts to the initial message with left arrow, right arrow, and check mark
-        for i in valid_emoji:
-            try:
-                await message.add_reaction(i)
-            except discord.HTTPException:
-                return
-
-        # Loops until checkmark is reacted
-        index = 0
-        while True:
-
-            # Checks that author is who typed the command and that the emoji reacted by the user is in validEmoji
-            def check(reaction, user):
-                return user == ctx.author and str(reaction.emoji) in valid_emoji
-
-            # Waits for the reaction from the user
-            try:
-                reaction, _ = await self.bot.wait_for('reaction_add', timeout=300.0, check=check)
-            except asyncio.TimeoutError:
-                reaction.emoji = valid_emoji[2]
-
-            # Checks which emoji was reacted and add to the index
-            if reaction.emoji == valid_emoji[0]:
-                new_index = index + 1
-            if reaction.emoji == valid_emoji[1]:
-                new_index = index - 1
-            if reaction.emoji == valid_emoji[2]:
-                break
-
-            # See if our index has changed
-            new_index = max(0, new_index)
-            new_index = min(len(pages), new_index)
-            if new_index == index:
-                continue
-            index = new_index
-
-            # Update the message
-            try:
-                await message.edit(content=pages[index])
-            except discord.HTTPException:
-                return
-
-        # Removes the reactions from the initial message
-        for i in valid_emoji:
-            try:
-                await message.remove_reaction(i)
-            except discord.HTTPException:
-                pass
+        # Paginate
+        await utils.Paginator(pages, per_page=1).start(ctx)
 
     @commands.command(aliases=['pm', 'dm', 'send'], cls=utils.Command)
     @commands.is_owner()
@@ -155,7 +106,9 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         await ctx.okay()
 
     def _cleanup_code(self, content):
-        """Automatically removes code blocks from the code."""
+        """
+        Automatically removes code blocks from the code.
+        """
 
         # remove ```py\n```
         if content.startswith('```') and content.endswith('```'):
@@ -166,15 +119,28 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         # remove `foo`
         return content.strip('` \n')
 
+    @staticmethod
+    def get_execution_time(end, start) -> str:
+        """
+        Gets the execution time string for the ev command.
+        """
+
+        time_taken = end - start
+        precision = "seconds"
+        prefixes = ["milli", "micro", "nano", "pico"]
+        index = 1
+        while float(format(time_taken, ",.3f")) < 10:
+            time_taken *= 1_000
+            precision = f"{prefixes[index]}seconds"
+            index += 1
+        return f"Executed in **{time_taken:.3f}** {precision}."
+
     @commands.command(aliases=['evall', 'eval'], cls=utils.Command)
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
     async def ev(self, ctx:utils.Context, *, content:str):
         """
         Evaluates some Python code.
-
-        Gracefully stolen from Rapptz ->
-        https://github.com/Rapptz/RoboDanny/blob/rewrite/cogs/admin.py#L72-L117
         """
 
         # Make the environment
@@ -189,6 +155,14 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         }
         env.update(globals())
 
+        # See if the user attached a file (alix was here)
+        if ctx.message.attachments:
+            async with self.bot.session.get(ctx.message.attachments[0].url) as r:
+                try:
+                    content = await r.text()
+                except Exception:
+                    pass
+
         # Make code and output string
         content = self._cleanup_code(content)
         code = f'async def func():\n{textwrap.indent(content, "  ")}'
@@ -202,14 +176,16 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
 
         # Grab the function we just made and run it
         func = env['func']
+        start_time = time.perf_counter()
+        end_time = None
         try:
-            # Shove stdout into StringIO
             with contextlib.redirect_stdout(stdout):
                 ret = await func()
         except Exception:
-            # Oh no it caused an error
+            end_time = time.perf_counter()
             stdout_value = stdout.getvalue() or None
             return await ctx.send(f'```py\n{stdout_value}\n{traceback.format_exc()}\n```', embeddify=False)
+        end_time = time.perf_counter()
 
         # Oh no it didn't cause an error
         stdout_value = stdout.getvalue() or None
@@ -224,7 +200,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
         if ret is None:
             # It might have printed something
             if stdout_value is not None:
-                await ctx.send(f'```py\n{stdout_value}\n```', embeddify=False)
+                await ctx.send(f'```py\n{stdout_value}\n```{self.get_execution_time(end_time, start_time)}', embeddify=False)
             return
 
         # If the function did return a value
@@ -240,11 +216,12 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
                 pass
             else:
                 text = f'```json\n{result}\n```'
+        text += self.get_execution_time(end_time, start_time)
 
         # Output to chat
         if len(text) > 2000:
             try:
-                return await ctx.send(file=discord.File(io.StringIO(result), filename='ev.txt'))
+                return await ctx.send(self.get_execution_time(end_time, start_time), file=discord.File(io.StringIO(result), filename='ev.txt'))
             except discord.HTTPException:
                 return await ctx.send("I don't have permission to attach files here.", embeddify=False)
         else:
