@@ -3,4 +3,5 @@ from .is_config_set import is_config_set
 from .meta_command import meta_command
 from .bot_is_ready import bot_is_ready
 from .is_bot_support import is_bot_support
-from .is_voter import is_voter, has_user_voted
+from .is_voter import is_voter
+from .is_upgrade_chat_subscriber import is_upgrade_chat_subscriber
