@@ -188,12 +188,21 @@ class Cooldown(commands.Cooldown):
         return self
 
 
+class NoRaiseCommandOnCooldown(commands.CommandOnCooldown):
+    """A version of :class:`commands.CommandOnCooldown` that doesn't output an error."""
+
+
+class NoRaiseCooldown(Cooldown):
+
+    default_cooldown_error = NoRaiseCommandOnCooldown
+
+
 def cooldown(rate:int, per:int, type:commands.BucketType=commands.BucketType.default, *, cls:commands.Cooldown=None) -> typing.Callable:
     """
     Args:
         rate (int): How many times this command can be run.
         per (int): The time before which the cooldown for this command is reset.
-        type (commands.BucketType, optional): The bucked that the cooldown should be applied for.
+        type (commands.BucketType, optional): The bucket that the cooldown should be applied for.
         cls (commands.Cooldown, optional): The cooldown class instance.
 
     Returns:
