@@ -5,13 +5,13 @@ from .cooldown import Cooldown
 
 class CooldownWithChannelExemptions(Cooldown):
     """
-    A custom cooldown which allows for channel white/blacklisting by name.
+    A custom cooldown which allows for channel allow/deny listing by name.
 
     Params:
         cooldown_in : typing.List[str]
-            A list of channel names where the cooldown should apply. If left blank, it'll apply everywhere minus the blacklist given.
+            A list of channel names where the cooldown should apply. If left blank, it'll apply everywhere minus the deny list given.
         no_cooldown_in : typing.List[str]
-            A list of channel names where the cooldown shouldn't apply. If left blank, it won't apply anywhere apart from the whitelist.
+            A list of channel names where the cooldown shouldn't apply. If left blank, it won't apply anywhere apart from the allow list.
     """
 
     _copy_kwargs = ('cooldown_in', 'no_cooldown_in')
@@ -19,17 +19,17 @@ class CooldownWithChannelExemptions(Cooldown):
     def __init__(self, *, cooldown_in:list=None, no_cooldown_in:list=None, **kwargs):
         """
         Args:
-            cooldown_in (list, optional): A list of channel names where the cooldown should apply. If left blank, it'll apply everywhere minus the blacklist given.
-            no_cooldown_in (list, optional): A list of channel names where the cooldown shouldn't apply. If left blank, it won't apply anywhere apart from the whitelist.
+            cooldown_in (list, optional): A list of channel names where the cooldown should apply. If left blank, it'll apply everywhere minus the deny list given.
+            no_cooldown_in (list, optional): A list of channel names where the cooldown shouldn't apply. If left blank, it won't apply anywhere apart from the allow list.
             **kwargs: The default kwargs to be passed to the original cooldown class.
 
         Raises:
-            ValueError: There are no channels set to blacklist or whitelist.
+            ValueError: There are no channels set to deny or allow.
         """
 
         super().__init__(**kwargs)
         if cooldown_in is None and no_cooldown_in is None:
-            raise ValueError("You need to set at least one channel in your blacklist/whitelist")
+            raise ValueError("You need to set at least one channel in your deny list/allow list")
         self.cooldown_in = cooldown_in or []
         self.no_cooldown_in = no_cooldown_in or []
 
