@@ -3,5 +3,5 @@ from .user_id import UserID
 from .channel_id import ChannelID
 from .enum_converter import EnumConverter
 from .boolean_converter import BooleanConverter
-from .colour_converter import CustomColourConverter as ColourConverter
+from .colour_converter import ColourConverter
 from .filtered_user import FilteredUser, FilteredMember
