@@ -13,146 +13,141 @@ https://github.com/bahamas10/css-color-names/blob/master/css-color-names.json
 
 
 COLOURS_BY_NAME = {
+
+    # Custom colours
     "kae blue": 0x5dadec,
     "ollie yellow": 0xf5e59d,
     "poop brown": 0x7a5901,
     "stegosans": 0xf1e6a9,
     "teddy purple": 0xb19cd9,
+    "medusa green": 0x173b0b,
 
-    # Below this point is directly copied from the Github link,
-    # minus a bunch that were repeated colours later
-    "alice blue": 0xf0f8ff,
-    "antique white": 0xfaebd7,
-    "aquamarine": 0x7fffd4,
-    "beige": 0xf5f5dc,
-    "bisque": 0xffe4c4,
-    "black": 0x000001,
-    "blanched almond": 0xffebcd,
-    "blue": 0x0000ff,
-    "blue violet": 0x8a2be2,
-    "cadet blue": 0x5f9ea0,
-    "chartreuse": 0x7fff00,
-    "chocolate": 0xd2691e,
-    "coral": 0xff7f50,
-    "cornflower blue": 0x6495ed,
-    "cornsilk": 0xfff8dc,
-    "crimson": 0xdc143c,
-    "cyan": 0x00ffff,
-    "dark blue": 0x00008b,
-    "dark cyan": 0x008b8b,
-    "dark goldenrod": 0xb8860b,
-    "dark grey": 0xa9a9a9,
-    "dark khaki": 0xbdb76b,
-    "dark magenta": 0x8b008b,
-    "dark orange": 0xff8c00,
-    "dark orchid": 0x9932cc,
-    "dark red": 0x8b0000,
-    "dark salmon": 0xe9967a,
-    "dark sea green": 0x8fbc8f,
-    "dark slate blue": 0x483d8b,
-    "dark slate grey": 0x2f4f4f,
-    "dark turquoise": 0x00ced1,
-    "dark violet": 0x9400d3,
-    "deep pink": 0xff1493,
-    "deep sky blue": 0x00bfff,
-    "dim grey": 0x696969,
-    "dodger blue": 0x1e90ff,
-    "floral white": 0xfffaf0,
-    "forest green": 0x228b22,
-    "frank green": 0x9acd32,
-    "gainsboro": 0xdcdcdc,
-    "ghost white": 0xf8f8ff,
-    "goldenrod": 0xdaa520,
-    "green yellow": 0xadff2f,
-    "grey": 0x808080,
-    "honeydew": 0xf0fff0,
-    "hot pink": 0xff69b4,
-    "indian red": 0xcd5c5c,
-    "indigo": 0x4b0082,
-    "ivory": 0xfffff0,
-    "khaki": 0xf0e68c,
-    "lavender": 0xe6e6fa,
-    "lavender blush": 0xfff0f5,
-    "lawn green": 0x7cfc00,
-    "lemon chiffon": 0xfffacd,
-    "light blue": 0xadd8e6,
-    "light coral": 0xf08080,
-    "light cyan": 0xe0ffff,
-    "light goldenrod yellow": 0xfafad2,
-    "light green": 0x90ee90,
-    "light grey": 0xd3d3d3,
-    "light pink": 0xffb6c1,
-    "light salmon": 0xffa07a,
-    "light sea green": 0x20b2aa,
-    "light sky blue": 0x87cefa,
-    "light slate grey": 0x778899,
-    "light steel blue": 0xb0c4de,
-    "light yellow": 0xffffe0,
-    "lime green": 0x32cd32,
-    "linen": 0xfaf0e6,
-    "magenta": 0xff00ff,
-    "malachite": 0x0bda51,
-    "maroon": 0x800000,
-    "medium blue": 0x0000cd,
-    "medium orchid": 0xba55d3,
-    "medium purple": 0x9370db,
-    "medium sea green": 0x3cb371,
-    "medium slate blue": 0x7b68ee,
-    "medium spring green": 0x00fa9a,
-    "medium turquoise": 0x48d1cc,
-    "medium violet red": 0xc71585,
-    "midnight blue": 0x191970,
-    "mint cream": 0xf5fffa,
-    "misty rose": 0xffe4e1,
-    "moccasin": 0xffe4b5,
-    "navajo white": 0xffdead,
-    "old lace": 0xfdf5e6,
-    "olive": 0x808000,
-    "olive drab": 0x6b8e23,
-    "ollie yellow": 0xf5e59d,
-    "orange red": 0xff4500,
-    "orchid": 0xda70d6,
-    "pale goldenrod": 0xeee8aa,
-    "pale green": 0x98fb98,
-    "pale turquoise": 0xafeeee,
-    "pale violet red": 0xdb7093,
-    "papaya whip": 0xffefd5,
-    "peach puff": 0xffdab9,
-    "peru": 0xcd853f,
-    "pink": 0xffc0cb,
-    "poop brown": 0x7a5901,
-    "powder blue": 0xb0e0e6,
-    "rebecca purple": 0x663399,
-    "red": 0xff0000,
-    "rosy brown": 0xbc8f8f,
-    "royal blue": 0x4169e1,
-    "saddle brown": 0x8b4513,
-    "salmon": 0xfa8072,
-    "sandy brown": 0xf4a460,
-    "sea green": 0x2e8b57,
-    "seashell": 0xfff5ee,
-    "silver": 0xc0c0c0,
-    "sky blue": 0x87ceeb,
-    "slate blue": 0x6a5acd,
-    "slate grey": 0x708090,
-    "snow": 0xfffafa,
-    "spring green": 0x00ff7f,
-    "steel blue": 0x4682b4,
-    "stegosans": 0xf1e6a9,
-    "tan": 0xd2b48c,
-    "teal": 0x008080,
-    "thistle": 0xd8bfd8,
-    "tomato": 0xff6347,
-    "turquoise": 0x40e0d0,
-    "wheat": 0xf5deb3,
-    "white": 0xffffff,
-    "white smoke": 0xf5f5f5,
-    "yellow": 0xffff00,
-    "paynes grey": 0x536878,
-
-    # Below this point is directly copied from the Wikipedia list of colours
-    # APART FROM black, which has been changed from 0 to 1 because
-    # of how Discord works out its colours
+    # Actual real colours
+    "alice blue": 15792383,
+    "antique white": 16444375,
+    "aquamarine": 8388564,
+    "beige": 16119260,
+    "bisque": 16770244,
+    "black": 1,
+    "blanched almond": 16772045,
+    "blue": 255,
+    "blue violet": 9055202,
+    "cadet blue": 6266528,
+    "chartreuse": 8388352,
+    "chocolate": 13789470,
+    "coral": 16744272,
+    "cornflower blue": 6591981,
+    "cornsilk": 16775388,
+    "crimson": 14423100,
+    "cyan": 65535,
+    "dark blue": 139,
+    "dark cyan": 35723,
+    "dark goldenrod": 12092939,
+    "dark grey": 11119017,
+    "dark khaki": 12433259,
+    "dark magenta": 9109643,
+    "dark orange": 16747520,
+    "dark orchid": 10040012,
+    "dark red": 9109504,
+    "dark salmon": 15308410,
+    "dark sea green": 9419919,
+    "dark slate blue": 4734347,
+    "dark slate grey": 3100495,
+    "dark turquoise": 52945,
+    "dark violet": 9699539,
+    "deep pink": 16716947,
+    "deep sky blue": 49151,
+    "dim grey": 6908265,
+    "dodger blue": 2003199,
+    "floral white": 16775920,
+    "forest green": 2263842,
+    "frank green": 10145074,
+    "gainsboro": 14474460,
+    "ghost white": 16316671,
+    "goldenrod": 14329120,
+    "green yellow": 11403055,
+    "grey": 8421504,
+    "honeydew": 15794160,
+    "hot pink": 16738740,
+    "indian red": 13458524,
+    "indigo": 4915330,
+    "ivory": 16777200,
+    "khaki": 15787660,
+    "lavender": 15132410,
+    "lavender blush": 16773365,
+    "lawn green": 8190976,
+    "lemon chiffon": 16775885,
+    "light blue": 11393254,
+    "light coral": 15761536,
+    "light cyan": 14745599,
+    "light goldenrod yellow": 16448210,
+    "light green": 9498256,
+    "light grey": 13882323,
+    "light pink": 16758465,
+    "light salmon": 16752762,
+    "light sea green": 2142890,
+    "light sky blue": 8900346,
+    "light slate grey": 7833753,
+    "light steel blue": 11584734,
+    "light yellow": 16777184,
+    "lime green": 3329330,
+    "linen": 16445670,
+    "magenta": 16711935,
+    "malachite": 776785,
+    "maroon": 8388608,
+    "medium blue": 205,
+    "medium orchid": 12211667,
+    "medium purple": 9662683,
+    "medium sea green": 3978097,
+    "medium slate blue": 8087790,
+    "medium spring green": 64154,
+    "medium turquoise": 4772300,
+    "medium violet red": 13047173,
+    "midnight blue": 1644912,
+    "mint cream": 16121850,
+    "misty rose": 16770273,
+    "moccasin": 16770229,
+    "navajo white": 16768685,
+    "old lace": 16643558,
+    "olive": 8421376,
+    "olive drab": 7048739,
+    "orange red": 16729344,
+    "orchid": 14315734,
+    "pale goldenrod": 15657130,
+    "pale green": 10025880,
+    "pale turquoise": 11529966,
+    "pale violet red": 14381203,
+    "papaya whip": 16773077,
+    "peach puff": 16767673,
+    "peru": 13468991,
+    "pink": 16761035,
+    "powder blue": 11591910,
+    "rebecca purple": 6697881,
+    "red": 16711680,
+    "rosy brown": 12357519,
+    "royal blue": 4286945,
+    "saddle brown": 9127187,
+    "salmon": 16416882,
+    "sandy brown": 16032864,
+    "sea green": 3050327,
+    "seashell": 16774638,
+    "silver": 12632256,
+    "sky blue": 8900331,
+    "slate blue": 6970061,
+    "slate grey": 7372944,
+    "snow": 16775930,
+    "spring green": 65407,
+    "steel blue": 4620980,
+    "tan": 13808780,
+    "teal": 32896,
+    "thistle": 14204888,
+    "tomato": 16737095,
+    "turquoise": 4251856,
+    "wheat": 16113331,
+    "white": 16777215,
+    "white smoke": 16119285,
+    "yellow": 16776960,
+    "paynes grey": 5466232,
     "absolute zero": 18618,
     "acid green": 11583258,
     "aero": 8174056,
@@ -160,7 +155,6 @@ COLOURS_BY_NAME = {
     "african violet": 11699390,
     "air superiority blue": 7512257,
     "alabaster": 15592160,
-    "alice blue": 15792383,
     "alloy orange": 12870160,
     "almond": 15720141,
     "amaranth": 15018832,
@@ -175,10 +169,8 @@ COLOURS_BY_NAME = {
     "antique bronze": 6708510,
     "antique fuchsia": 9526403,
     "antique ruby": 8657709,
-    "antique white": 16444375,
     "apple green": 9287168,
     "apricot": 16502449,
-    "aquamarine": 8388564,
     "arctic lime": 13696788,
     "army green": 4936480,
     "artichoke": 9410425,
@@ -199,29 +191,24 @@ COLOURS_BY_NAME = {
     "barn red": 8129026,
     "beau blue": 12375270,
     "beaver": 10453360,
-    "beige": 16119260,
     "b'dazzled blue": 3037332,
     "big dip o\u00e2\u20ac\u2122ruby": 10233154,
-    "bisque": 16770244,
     "bistre": 4008735,
     "bitter lemon": 13295629,
     "bitter lime": 12582656,
     "bittersweet": 16674654,
     "bittersweet shimmer": 12537681,
-    "black": 1,
     "black bean": 4000770,
     "black chocolate": 1775633,
     "black coffee": 3878703,
     "black coral": 5530223,
     "black olive": 3882038,
     "black shadows": 12562354,
-    "blanched almond": 16772045,
     "blast-off bronze": 10842468,
     "bleu de france": 3247335,
     "blizzard blue": 11331054,
     "blond": 16445630,
     "blood red": 6684672,
-    "blue": 255,
     "blue bell": 10658512,
     "blue-green": 891066,
     "blue sapphire": 1204608,
@@ -254,7 +241,6 @@ COLOURS_BY_NAME = {
     "byzantine": 12399524,
     "byzantium": 7350627,
     "cadet": 5466226,
-    "cadet blue": 6266528,
     "cadet grey": 9544624,
     "cadmium green": 27452,
     "cadmium orange": 15566637,
@@ -316,18 +302,13 @@ COLOURS_BY_NAME = {
     "copper red": 13331793,
     "copper rose": 10053222,
     "coquelicot": 16726016,
-    "coral": 16744272,
     "coral pink": 16286585,
     "cordovan": 8994629,
-    "cornflower blue": 6591981,
-    "cornsilk": 16775388,
     "cosmic cobalt": 3026312,
     "cosmic latte": 16775399,
     "coyote brown": 8479036,
     "cotton candy": 16760025,
     "cream": 16776656,
-    "crimson": 14423100,
-    "cyan": 65535,
     "cyber grape": 5784188,
     "cyber yellow": 16765696,
     "cyclamen": 16084897,
@@ -335,42 +316,27 @@ COLOURS_BY_NAME = {
     "dark brown": 6636321,
     "dark byzantium": 6109524,
     "dark cornflower blue": 2507403,
-    "dark cyan": 35723,
-    "dark goldenrod": 12092939,
     "dark green": 78368,
     "dark jungle green": 1713185,
-    "dark khaki": 12433259,
     "dark liver": 5458767,
-    "dark magenta": 9109643,
     "dark moss green": 4873507,
     "dark olive green": 5597999,
-    "dark orange": 16747520,
-    "dark orchid": 10040012,
     "dark pastel green": 245820,
     "dark purple": 3152180,
-    "dark red": 9109504,
-    "dark salmon": 15308410,
-    "dark sea green": 9419919,
     "dark sienna": 3937300,
     "dark sky blue": 9223894,
-    "dark slate blue": 4734347,
     "dark spring green": 1536581,
-    "dark turquoise": 52945,
-    "dark violet": 9699539,
     "dartmouth green": 28732,
     "davy's grey": 5592405,
     "deep cerise": 14299783,
     "deep chestnut": 12144200,
     "deep jungle green": 19273,
-    "deep pink": 16716947,
     "deep saffron": 16750899,
-    "deep sky blue": 49151,
     "deep space sparkle": 4875372,
     "deep taupe": 8281696,
     "denim": 1401021,
     "denim blue": 2245558,
     "desert sand": 15583663,
-    "dodger blue": 2003199,
     "dogwood rose": 14096488,
     "drab": 9859351,
     "duke blue": 156,
@@ -409,7 +375,6 @@ COLOURS_BY_NAME = {
     "flame": 14833698,
     "flax": 15654018,
     "flirt": 10616941,
-    "floral white": 16775920,
     "fluorescent blue": 1438958,
     "french beige": 10910555,
     "french bistre": 8744269,
@@ -428,10 +393,8 @@ COLOURS_BY_NAME = {
     "fuchsia rose": 13058933,
     "fulvous": 14976000,
     "fuzzy wuzzy": 8864287,
-    "gainsboro": 14474460,
     "gamboge": 14981903,
     "generic viridian": 32614,
-    "ghost white": 16316671,
     "glaucous": 6324918,
     "glossy grape": 11244211,
     "go green": 43878,
@@ -440,7 +403,6 @@ COLOURS_BY_NAME = {
     "golden brown": 10052885,
     "golden poppy": 16564736,
     "golden yellow": 16768768,
-    "goldenrod": 14329120,
     "granite gray": 6776679,
     "granny smith apple": 11068576,
     "green": 65280,
@@ -456,11 +418,9 @@ COLOURS_BY_NAME = {
     "harvest gold": 14323968,
     "heat wave": 16742912,
     "heliotrope": 14644223,
-    "honeydew": 15794160,
     "honolulu blue": 28080,
     "hooker's green": 4815211,
     "hot magenta": 16719310,
-    "hot pink": 16738740,
     "hunter green": 3497531,
     "iceberg": 7448274,
     "icterine": 16578398,
@@ -469,14 +429,11 @@ COLOURS_BY_NAME = {
     "inchworm": 11725917,
     "independence": 5001581,
     "india green": 1280008,
-    "indian red": 13458524,
     "indian yellow": 14919767,
-    "indigo": 4915330,
     "indigo dye": 16746,
     "iris": 5918671,
     "irresistible": 11748460,
     "isabelline": 16052460,
-    "ivory": 16777200,
     "jade": 43115,
     "japanese carmine": 10299699,
     "japanese violet": 5976662,
@@ -497,50 +454,32 @@ COLOURS_BY_NAME = {
     "lapis lazuli": 2515356,
     "laurel green": 11123357,
     "lava": 13570080,
-    "lavender blush": 16773365,
     "lavender gray": 12895184,
-    "lawn green": 8190976,
     "lemon": 16774912,
-    "lemon chiffon": 16775885,
     "lemon curry": 13410333,
     "lemon glacier": 16645888,
     "lemon meringue": 16181950,
     "lemon yellow": 16774223,
     "liberty": 5528231,
-    "light blue": 11393254,
-    "light coral": 15761536,
     "light cornflower blue": 9686250,
-    "light cyan": 14745599,
     "light french beige": 13151615,
-    "light goldenrod yellow": 16448210,
-    "light green": 9498256,
     "light orange": 16701617,
     "light periwinkle": 12962785,
-    "light pink": 16758465,
-    "light salmon": 16752762,
-    "light sea green": 2142890,
-    "light sky blue": 8900346,
-    "light steel blue": 11584734,
-    "light yellow": 16777184,
     "lilac": 13148872,
     "lilac luster": 11442346,
-    "lime green": 3329330,
     "lincoln green": 1661189,
-    "linen": 16445670,
     "liseran purple": 14577569,
     "little boy blue": 7119068,
     "liver": 6769735,
     "liver chestnut": 9991254,
     "macaroni and cheese": 16760200,
     "madder lake": 13382454,
-    "magenta": 16711935,
     "magenta haze": 10438006,
     "magic mint": 11202769,
     "magnolia": 15919319,
     "mahogany": 12599296,
     "maize": 16510045,
     "majorelle blue": 6312156,
-    "malachite": 776785,
     "manatee": 9935530,
     "mandarin": 15956552,
     "mango": 16629250,
@@ -564,15 +503,8 @@ COLOURS_BY_NAME = {
     "may green": 5017921,
     "maya blue": 7586555,
     "medium aquamarine": 6741418,
-    "medium blue": 205,
     "medium candy apple red": 14812716,
     "medium carmine": 11485237,
-    "medium orchid": 12211667,
-    "medium purple": 9662683,
-    "medium sea green": 3978097,
-    "medium slate blue": 8087790,
-    "medium spring green": 64154,
-    "medium turquoise": 4772300,
     "mellow apricot": 16300152,
     "melon": 16693933,
     "metallic gold": 13872951,
@@ -591,17 +523,14 @@ COLOURS_BY_NAME = {
     "middle yellow": 16771840,
     "middle yellow red": 15511926,
     "midnight": 7349872,
-    "midnight blue": 1644912,
     "mikado yellow": 16761868,
     "mimi pink": 16767721,
     "mindaro": 14940552,
     "ming": 3568765,
     "minion yellow": 16113744,
     "mint": 4109449,
-    "mint cream": 16121850,
     "mint green": 10026904,
     "misty moss": 12301431,
-    "misty rose": 16770273,
     "morning blue": 9282457,
     "moss green": 9083483,
     "mountain meadow": 3193487,
@@ -614,7 +543,6 @@ COLOURS_BY_NAME = {
     "mystic maroon": 11355001,
     "nadeshiko pink": 16166342,
     "naples yellow": 16439902,
-    "navajo white": 16768685,
     "navy blue": 128,
     "neon blue": 4613887,
     "neon carrot": 16753475,
@@ -629,11 +557,9 @@ COLOURS_BY_NAME = {
     "ochre": 13399842,
     "old burgundy": 4403246,
     "old gold": 13612347,
-    "old lace": 16643558,
     "old lavender": 7956600,
     "old rose": 12615809,
     "old silver": 8684674,
-    "olive": 8421376,
     "olive drab #7": 3945503,
     "olive green": 11907932,
     "olivine": 10140019,
@@ -645,7 +571,6 @@ COLOURS_BY_NAME = {
     "orange-red": 16738335,
     "orange soda": 16407357,
     "orange-yellow": 16104735,
-    "orchid": 14315734,
     "orchid pink": 15908301,
     "outrageous orange": 16739914,
     "oxford blue": 8519,
@@ -659,12 +584,10 @@ COLOURS_BY_NAME = {
     "pale spring bud": 15526845,
     "pansy purple": 7870538,
     "paolo veronese green": 39805,
-    "papaya whip": 16773077,
     "paradise pink": 15089250,
     "pastel pink": 14591396,
     "patriarch": 8388736,
     "peach": 16770484,
-    "peach puff": 16767673,
     "pear": 13754929,
     "pearly purple": 12019874,
     "periwinkle": 13421823,
@@ -686,7 +609,6 @@ COLOURS_BY_NAME = {
     "piggy pink": 16637414,
     "pine green": 96623,
     "pine tree": 2764579,
-    "pink": 16761035,
     "pink flamingo": 16545021,
     "pink lace": 16768500,
     "pink lavender": 14201553,
@@ -698,7 +620,6 @@ COLOURS_BY_NAME = {
     "polished pine": 6136979,
     "popstar": 12472162,
     "portland orange": 16734774,
-    "powder blue": 11591910,
     "princeton orange": 16089125,
     "prune": 7347228,
     "prussian blue": 12627,
@@ -723,8 +644,6 @@ COLOURS_BY_NAME = {
     "razzle dazzle rose": 16724940,
     "razzmatazz": 14886251,
     "razzmic berry": 9260677,
-    "rebecca purple": 6697881,
-    "red": 16711680,
     "red-orange": 16733001,
     "red-purple": 14942328,
     "red salsa": 16595530,
@@ -748,7 +667,6 @@ COLOURS_BY_NAME = {
     "rose vale": 11226706,
     "rosewood": 6619147,
     "rosso corsa": 13893632,
-    "rosy brown": 12357519,
     "royal purple": 7885225,
     "ruber": 13518454,
     "rubine red": 13697110,
@@ -761,16 +679,13 @@ COLOURS_BY_NAME = {
     "rust": 12009742,
     "rusty red": 14298179,
     "sacramento state green": 276775,
-    "saddle brown": 9127187,
     "safety orange": 16742400,
     "safety yellow": 15651330,
     "saffron": 16041008,
     "sage": 12368010,
     "st. patrick's blue": 2304378,
-    "salmon": 16416882,
     "salmon pink": 16748964,
     "sand": 12759680,
-    "sandy brown": 16032864,
     "sap green": 5274922,
     "sapphire": 1004218,
     "sapphire blue": 26533,
@@ -779,9 +694,7 @@ COLOURS_BY_NAME = {
     "schauss pink": 16748975,
     "school bus yellow": 16766976,
     "screamin' green": 6750054,
-    "sea green": 3050327,
     "seal brown": 5842443,
-    "seashell": 16774638,
     "selective yellow": 16759296,
     "sepia": 7356948,
     "shadow": 9075037,
@@ -792,7 +705,6 @@ COLOURS_BY_NAME = {
     "shiny shamrock": 6268792,
     "shocking pink": 16519104,
     "sienna": 8924439,
-    "silver": 12632256,
     "silver chalice": 11316396,
     "silver pink": 12889773,
     "silver sand": 12566978,
@@ -800,13 +712,10 @@ COLOURS_BY_NAME = {
     "sizzling red": 16726101,
     "sizzling sunrise": 16767744,
     "skobeloff": 29812,
-    "sky blue": 8900331,
     "sky magenta": 13595055,
-    "slate blue": 6970061,
     "slimy green": 2725399,
     "smitten": 13123974,
     "smoky black": 1051656,
-    "snow": 16775930,
     "solid pink": 8992835,
     "sonic silver": 7697781,
     "space cadet": 1911121,
@@ -822,9 +731,7 @@ COLOURS_BY_NAME = {
     "spanish viridian": 32604,
     "spring bud": 11009024,
     "spring frost": 8912682,
-    "spring green": 65407,
     "star command blue": 31672,
-    "steel blue": 4620980,
     "steel pink": 13382604,
     "steel teal": 6261387,
     "straw": 14997871,
@@ -834,28 +741,23 @@ COLOURS_BY_NAME = {
     "sunset": 16438949,
     "super pink": 13593513,
     "sweet brown": 11024177,
-    "tan": 13808780,
     "tangerine": 15893760,
     "tart orange": 16469318,
     "taupe": 4734002,
     "taupe gray": 9143689,
     "tea green": 13693120,
-    "teal": 32896,
     "teal blue": 3569032,
     "telemagenta": 13579382,
     "terra cotta": 14840411,
-    "thistle": 14204888,
     "tickle me pink": 16550316,
     "tiffany blue": 703157,
     "timberwolf": 14407634,
     "titanium yellow": 15656448,
-    "tomato": 16737095,
     "tropical rainforest": 30046,
     "true blue": 2975940,
     "trypan blue": 1836467,
     "tufts blue": 4099806,
     "tumbleweed": 14592648,
-    "turquoise": 4251856,
     "turquoise blue": 65519,
     "turquoise green": 10540724,
     "tuscan red": 8144968,
@@ -895,8 +797,6 @@ COLOURS_BY_NAME = {
     "vivid violet": 10420479,
     "volt": 13565696,
     "warm black": 16962,
-    "wheat": 16113331,
-    "white": 16777215,
     "wild blue yonder": 10661328,
     "wild orchid": 13922466,
     "wild strawberry": 16728996,
@@ -910,11 +810,10 @@ COLOURS_BY_NAME = {
     "xanthic": 15658249,
     "xanadu": 7571064,
     "yale blue": 1002898,
-    "yellow": 16776960,
     "yellow orange": 16756290,
     "yinmn blue": 3035280,
     "zaffre": 5288,
-    "zomp": 3778446
+    "zomp": 3778446,
 }
 COLOURS_BY_VALUE = {o:i for i, o in COLOURS_BY_NAME.items()}
 
