@@ -6,25 +6,27 @@ import asyncpg
 
 class DatabaseConnection(object):
     """
-    A helper class to wrap around an asyncpg.Connection object so as to make it a little easier to use.
+    A helper class to wrap around an :class:`asyncpg.Connection` object.
     """
 
     config: dict = None
     pool: asyncpg.pool.Pool = None
     logger: logging.Logger = None
-    __slots__ = ('conn', 'transaction')
+    __slots__ = ('conn', 'transaction', 'is_active',)
 
     def __init__(self, connection:asyncpg.Connection=None, transaction:asyncpg.transaction.Transaction=None):
+        """:meta private:"""
         self.conn = connection
         self.transaction = transaction
+        self.is_active = False
 
     @classmethod
     async def create_pool(cls, config:dict) -> None:
         """
-        Creates the database pool and plonks it in DatabaseConnection.pool.
+        Creates the database pool and plonks it in :attr:`DatabaseConnection.pool`.
 
         Args:
-            config (dict): The configuration for the dictionary, passed directly to `asyncpg.create_pool` as kwargs.
+            config (dict): The configuration for the dictionary, passed directly to :func:`asyncpg.create_pool` as kwargs.
         """
 
         cls.config = config.copy()
@@ -44,7 +46,9 @@ class DatabaseConnection(object):
         """
 
         conn = await cls.pool.acquire()
-        return cls(conn)
+        v = cls(conn)
+        v.is_active = True
+        return v
 
     async def disconnect(self) -> None:
         """
@@ -53,6 +57,7 @@ class DatabaseConnection(object):
 
         await self.pool.release(self.conn)
         self.conn = None
+        self.is_active = False
         del self
 
     async def start_transaction(self):
@@ -65,15 +70,18 @@ class DatabaseConnection(object):
 
     async def commit_transaction(self):
         """
-        Commits the transaction wew lad.
+        Commits the current transaction.
         """
 
         await self.transaction.commit()
         self.transaction = None
 
     async def __aenter__(self):
+        if self.is_active:
+            raise Exception("Can't open a new database connection while currently connected.")
         v = await self.get_connection()
         self.conn = v.conn
+        self.is_active = True
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
@@ -81,8 +89,7 @@ class DatabaseConnection(object):
 
     async def __call__(self, sql:str, *args) -> typing.Union[typing.List[dict], None]:
         """
-        Runs a line of SQL and returns a list, if things are expected back,
-        or None, if nothing of interest is happening.
+        Runs a line of SQL and returns a list, if things are expected back, or None, if nothing of interest is happening.
 
         Args:
             sql (str): The SQL that you want to run.
