@@ -3,22 +3,17 @@ import asyncio
 import logging
 import sys
 import typing
+import os
+import importlib
 
 from .cogs.utils.database import DatabaseConnection
 from .cogs.utils.redis import RedisConnection
+from .cogs.utils.statsd import StatsdConnection
 from .cogs.utils.custom_bot import Bot
 
 
-__all__ = (
-    'get_default_program_arguments',
-    'validate_sharding_information',
-    'set_default_log_levels',
-    'run_bot',
-)
-
-
 # Set up the loggers
-def set_log_level(logger_to_change:logging.Logger, log_level:str, minimum_level:int=None) -> None:
+def set_log_level(logger_to_change:typing.Union[logging.Logger, str], log_level:str, minimum_level:int=None) -> None:
     """
     Set a logger to a default log level
 
@@ -54,68 +49,12 @@ def set_log_level(logger_to_change:logging.Logger, log_level:str, minimum_level:
         logger_to_change.setLevel(level)
 
 
-# Parse arguments
-def get_default_program_arguments(include_config_file:bool=True) -> argparse.ArgumentParser:
-    """
-    Get the default commandline args for the file
-
-    Args:
-        include_config_file (bool, optional): Whether or not to include the config file arugment
-
-    Returns:
-        argparse.ArgumentParser: The arguments that were parsed
-    """
-    parser = argparse.ArgumentParser()
-    if include_config_file:
-        parser.add_argument(
-            "config_file", nargs="?", default="config/config.toml",
-            help="The configuration for the bot."
-        )
-    parser.add_argument(
-        "--min", type=int, default=None,
-        help="The minimum shard ID that this instance will run with (inclusive)."
-    )
-    parser.add_argument(
-        "--max", type=int, default=None,
-        help="The maximum shard ID that this instance will run with (inclusive)."
-    )
-    parser.add_argument(
-        "--shardcount", type=int, default=None,
-        help="The amount of shards that the bot should be using."
-    )
-    parser.add_argument(
-        "--loglevel", default="INFO",
-        help="Global logging level - probably most useful is INFO and DEBUG."
-    )
-    parser.add_argument(
-        "--loglevel-bot", default=None,
-        help="Logging level for the bot - probably most useful is INFO and DEBUG."
-    )
-    parser.add_argument(
-        "--loglevel-discord", default=None,
-        help="Logging level for discord - probably most useful is INFO and DEBUG."
-    )
-    parser.add_argument(
-        "--loglevel-database", default=None,
-        help="Logging level for database - probably most useful is INFO and DEBUG."
-    )
-    parser.add_argument(
-        "--loglevel-redis", default=None,
-        help="Logging level for redis - probably most useful is INFO and DEBUG."
-    )
-    parser.add_argument(
-        "--loglevel-statsd", default=None,
-        help="Logging level for statsd - probably most useful is INFO and DEBUG."
-    )
-    return parser
-
-
 # Set up loggers
-logger = logging.getLogger('vflbotutils')
+logger = logging.getLogger('voxelbotutils')
 
 
 # Make sure the sharding info provided is correctish
-def validate_sharding_information(args:argparse.Namespace) -> typing.List[int]:
+def validate_sharding_information(args:argparse.Namespace) -> typing.Optional[typing.List[int]]:
     """
     Validate the given shard information and make sure that what's passed in is accurate
 
@@ -127,9 +66,7 @@ def validate_sharding_information(args:argparse.Namespace) -> typing.List[int]:
     """
 
     if args.shardcount is None:
-        args.shardcount = 1
-        args.min = 0
-        args.max = 0
+        return None
     else:
         if args.min is None and args.max is None:
             args.min = 0
@@ -195,6 +132,10 @@ def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
     stats_stderr_logger = logging.StreamHandler(sys.stderr)
     discord_stdout_logger = logging.StreamHandler(sys.stdout)
     discord_stderr_logger = logging.StreamHandler(sys.stderr)
+    aiohttp_stdout_logger = logging.StreamHandler(sys.stdout)
+    aiohttp_stderr_logger = logging.StreamHandler(sys.stderr)
+    aiohttp_access_stdout_logger = logging.StreamHandler(sys.stdout)
+    aiohttp_access_stderr_logger = logging.StreamHandler(sys.stderr)
 
     # Add the filters for the stdout handlers
     bot_stdout_logger.addFilter(log_filter)
@@ -202,6 +143,8 @@ def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
     redis_stdout_logger.addFilter(log_filter)
     stats_stdout_logger.addFilter(log_filter)
     discord_stdout_logger.addFilter(log_filter)
+    aiohttp_stdout_logger.addFilter(log_filter)
+    aiohttp_access_stdout_logger.addFilter(log_filter)
 
     # Add our formatters
     bot_stdout_logger.setFormatter(formatter)
@@ -214,6 +157,10 @@ def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
     stats_stderr_logger.setFormatter(formatter)
     discord_stdout_logger.setFormatter(formatter)
     discord_stderr_logger.setFormatter(formatter)
+    aiohttp_stdout_logger.setFormatter(formatter)
+    aiohttp_stderr_logger.setFormatter(formatter)
+    aiohttp_access_stdout_logger.setFormatter(formatter)
+    aiohttp_access_stderr_logger.setFormatter(formatter)
 
     # Set all the loggers to debug
     set_log_level(bot.logger, 'DEBUG')
@@ -221,6 +168,8 @@ def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
     set_log_level(bot.redis.logger, 'DEBUG')
     set_log_level(bot.stats.logger, 'DEBUG')
     set_log_level('discord', 'DEBUG')
+    set_log_level('aiohttp', 'DEBUG')
+    set_log_level('aiohttp.access', 'DEBUG')
 
     # Set loglevel defaults for the stdout handlers
     set_log_level(bot_stdout_logger, args.loglevel)
@@ -228,6 +177,8 @@ def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
     set_log_level(redis_stdout_logger, args.loglevel)
     set_log_level(stats_stdout_logger, args.loglevel)
     set_log_level(discord_stdout_logger, args.loglevel)
+    set_log_level(aiohttp_stdout_logger, args.loglevel)
+    set_log_level(aiohttp_access_stdout_logger, args.loglevel)
 
     # Set loglevel default for the stderr handlers
     set_log_level(bot_stderr_logger, args.loglevel, logging.WARNING)
@@ -235,20 +186,8 @@ def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
     set_log_level(redis_stderr_logger, args.loglevel, logging.WARNING)
     set_log_level(stats_stderr_logger, args.loglevel, logging.WARNING)
     set_log_level(discord_stderr_logger, args.loglevel, logging.WARNING)
-
-    # Set loglevels for the stdouts via the commandline args
-    set_log_level(bot_stdout_logger, args.loglevel_bot)
-    set_log_level(database_stdout_logger, args.loglevel_database)
-    set_log_level(redis_stdout_logger, args.loglevel_redis)
-    set_log_level(stats_stdout_logger, args.loglevel_statsd)
-    set_log_level(discord_stdout_logger, args.loglevel_discord)
-
-    # Set loglevels for the stderrs via the commandline args
-    set_log_level(bot_stderr_logger, args.loglevel_bot, logging.WARNING)
-    set_log_level(database_stderr_logger, args.loglevel_database, logging.WARNING)
-    set_log_level(redis_stderr_logger, args.loglevel_redis, logging.WARNING)
-    set_log_level(stats_stderr_logger, args.loglevel_statsd, logging.WARNING)
-    set_log_level(discord_stderr_logger, args.loglevel_discord, logging.WARNING)
+    set_log_level(aiohttp_stdout_logger, args.loglevel, logging.WARNING)
+    set_log_level(aiohttp_access_stdout_logger, args.loglevel, logging.WARNING)
 
     # Add the stream handlers to the loggers
     bot.logger.addHandler(bot_stdout_logger)
@@ -261,9 +200,13 @@ def set_default_log_levels(bot:Bot, args:argparse.Namespace) -> None:
     bot.stats.logger.addHandler(stats_stderr_logger)
     logging.getLogger('discord').addHandler(discord_stdout_logger)
     logging.getLogger('discord').addHandler(discord_stderr_logger)
+    logging.getLogger('aiohttp').addHandler(aiohttp_stdout_logger)
+    logging.getLogger('aiohttp').addHandler(aiohttp_stderr_logger)
+    logging.getLogger('aiohttp.access').addHandler(aiohttp_access_stdout_logger)
+    logging.getLogger('aiohttp.access').addHandler(aiohttp_access_stderr_logger)
 
 
-async def create_initial_database(bot:Bot) -> None:
+async def create_initial_database(db) -> None:
     """
     Create the initial database using the internal database.psql file
     """
@@ -287,67 +230,63 @@ async def create_initial_database(bot:Bot) -> None:
             current_line = ''
 
     # Let's do it baybeee
-    async with bot.database() as db:
-        for i in create_table_statements:
-            if i and i.strip():
-                await db(i.strip())
+    for i in create_table_statements:
+        if i and i.strip():
+            await db(i.strip())
 
     # Sick we're done
     return True
 
 
-async def start_database_pool(bot:Bot) -> None:
+async def start_database_pool(config:dict) -> None:
     """
     Start the database pool connection
     """
 
     # Connect the database pool
-    if bot.config.get('database', {}).get('enabled', False):
-        logger.info("Creating database pool")
-        try:
-            await DatabaseConnection.create_pool(bot.config['database'])
-        except KeyError:
-            raise Exception("KeyError creating database pool - is there a 'database' object in the config?")
-        except ConnectionRefusedError:
-            raise Exception("ConnectionRefusedError creating database pool - did you set the right information in the config, and is the database running?")
-        except Exception:
-            raise Exception("Error creating database pool")
-        logger.info("Created database pool successfully")
-        logger.info("Creating initial database tables")
-        await create_initial_database(bot)
-    else:
-        logger.info("Database connection has been disabled")
+    logger.info("Creating database pool")
+    try:
+        await DatabaseConnection.create_pool(config['database'])
+    except KeyError:
+        raise Exception("KeyError creating database pool - is there a 'database' object in the config?")
+    except ConnectionRefusedError:
+        raise Exception("ConnectionRefusedError creating database pool - did you set the right information in the config, and is the database running?")
+    except Exception:
+        raise Exception("Error creating database pool")
+    logger.info("Created database pool successfully")
+    logger.info("Creating initial database tables")
+    async with DatabaseConnection() as db:
+        await create_initial_database(db)
 
 
-async def start_redis_pool(bot:Bot) -> None:
+async def start_redis_pool(config:dict) -> None:
     """
     Start the redis pool conneciton
     """
 
     # Connect the redis pool
-    if bot.config.get('redis', {}).get('enabled', False):
-        logger.info("Creating redis pool")
-        try:
-            await RedisConnection.create_pool(bot.config['redis'])
-        except KeyError:
-            raise KeyError("KeyError creating redis pool - is there a 'redis' object in the config?")
-        except ConnectionRefusedError:
-            raise ConnectionRefusedError("ConnectionRefusedError creating redis pool - did you set the right information in the config, and is the database running?")
-        except Exception:
-            raise Exception("Error creating redis pool")
-        logger.info("Created redis pool successfully")
-    else:
-        logger.info("Redis connection has been disabled")
+    logger.info("Creating redis pool")
+    try:
+        await RedisConnection.create_pool(config['redis'])
+    except KeyError:
+        raise KeyError("KeyError creating redis pool - is there a 'redis' object in the config?")
+    except ConnectionRefusedError:
+        raise ConnectionRefusedError("ConnectionRefusedError creating redis pool - did you set the right information in the config, and is the database running?")
+    except Exception:
+        raise Exception("Error creating redis pool")
+    logger.info("Created redis pool successfully")
 
 
-def run_bot(bot:Bot) -> None:
+def run_bot(args:argparse.Namespace) -> None:
     """
     Starts the bot, connects the database, runs the async loop forever
 
     Args:
-        bot (Bot): The bot you want to run
+        args (argparse.Namespace): The arguments namespace that wants to be run
     """
 
+    os.chdir(args.bot_directory)
+
     # Use right event loop
     try:
         import uvloop
@@ -358,16 +297,21 @@ def run_bot(bot:Bot) -> None:
         loop = asyncio.ProactorEventLoop()
         asyncio.set_event_loop(loop)
 
-    # Grab the event loop
+    # And run file
+    shard_ids = validate_sharding_information(args)
+    bot = Bot(shard_count=args.shardcount, shard_ids=shard_ids, config_file=args.config_file)
     loop = bot.loop
+    set_default_log_levels(bot, args)
 
     # Connect the database pool
-    db_connect_task = start_database_pool(bot)
-    loop.run_until_complete(db_connect_task)
+    if bot.config.get('database', {}).get('enabled', False):
+        db_connect_task = start_database_pool(bot.config)
+        loop.run_until_complete(db_connect_task)
 
     # Connect the redis pool
-    re_connect = start_redis_pool(bot)
-    loop.run_until_complete(re_connect)
+    if bot.config.get('redis', {}).get('enabled', False):
+        re_connect = start_redis_pool(bot.config)
+        loop.run_until_complete(re_connect)
 
     # Load the bot's extensions
     logger.info('Loading extensions... ')
@@ -384,7 +328,10 @@ def run_bot(bot:Bot) -> None:
     # We're now done running the bot, time to clean up and close
     if bot.config.get('database', {}).get('enabled', False):
         logger.info("Closing database pool")
-        loop.run_until_complete(DatabaseConnection.pool.close())
+        try:
+            loop.run_until_complete(asyncio.wait_for(DatabaseConnection.pool.close(), timeout=30.0))
+        except asyncio.TimeoutError:
+            logger.error("Couldn't gracefully close the database connection pool within 30 seconds")
     if bot.config.get('redis', {}).get('enabled', False):
         logger.info("Closing redis pool")
         RedisConnection.pool.close()
@@ -392,3 +339,157 @@ def run_bot(bot:Bot) -> None:
     logger.info("Closing asyncio loop")
     loop.stop()
     loop.close()
+
+
+def run_website(args:argparse.Namespace) -> None:
+    """
+    Starts the website, connects the database, logs in the specified bots, runs the async loop forever
+
+    Args:
+        args (argparse.Namespace): The arguments namespace that wants to be run
+    """
+
+    # Load our imports here so we don't need to require them all the time
+    from aiohttp.web import Application, AppRunner, TCPSite
+    from aiohttp_jinja2 import setup as jinja_setup
+    from aiohttp_session import setup as session_setup, SimpleCookieStorage
+    from aiohttp_session.cookie_storage import EncryptedCookieStorage as ECS
+    from jinja2 import FileSystemLoader
+    import toml
+    import re
+    import html
+    from datetime import datetime as dt
+    import markdown
+
+    os.chdir(args.website_directory)
+
+    # Use right event loop
+    try:
+        import uvloop
+        asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
+    except ImportError:
+        pass
+    if sys.platform == 'win32':
+        loop = asyncio.ProactorEventLoop()
+        asyncio.set_event_loop(loop)
+
+    # Read config
+    with open(args.config_file) as a:
+        config = toml.load(a)
+
+    # Create website object - don't start based on argv
+    app = Application(loop=asyncio.get_event_loop(), debug=args.debug)
+    app['static_root_url'] = '/static'
+    for route in config['routes']:
+        module = importlib.import_module(f"website.{route}", "temp")
+        app.router.add_routes(module.routes)
+    app.router.add_static('/static', os.getcwd() + '/website/static', append_version=True)
+
+    # Add middlewares
+    if args.debug:
+        session_setup(app, SimpleCookieStorage(max_age=1_000_000))
+    else:
+        session_setup(app, ECS(os.urandom(32), max_age=1_000_000))
+    jinja_env = jinja_setup(app, loader=FileSystemLoader(os.getcwd() + '/website/templates'))
+
+    # Add our jinja env filters
+    def regex_replace(string, find, replace):
+        return re.sub(find, replace, string, re.IGNORECASE | re.MULTILINE)
+    def escape_text(string):
+        return html.escape(string)
+    def timestamp(string):
+        return dt.fromtimestamp(float(string))
+    def int_to_hex(string):
+        return format(hex(int(string))[2:], "0>6")
+    def to_markdown(string):
+        return markdown.markdown(string, extensions=['extra'])
+    def display_mentions(string, users):
+        def get_display_name(group):
+            user = users.get(group.group('userid'))
+            if not user:
+                return 'unknown-user'
+            return user.get('display_name') or user.get('username')
+        return re.sub(
+            '(?:<|(?:&lt;))@!?(?P<userid>\\d{16,23})(?:>|(?:&gt;))',
+            lambda g: f'<span class="chatlog__mention">@{get_display_name(g)}</span>',
+            string,
+            re.IGNORECASE | re.MULTILINE
+        )
+    jinja_env.filters['regex_replace'] = regex_replace
+    jinja_env.filters['escape_text'] = escape_text
+    jinja_env.filters['timestamp'] = timestamp
+    jinja_env.filters['int_to_hex'] = int_to_hex
+    jinja_env.filters['markdown'] = to_markdown
+    jinja_env.filters['display_mentions'] = display_mentions
+
+    # Add our connections and their loggers
+    app['database'] = DatabaseConnection
+    DatabaseConnection.logger = logger.getChild("database")
+    app['redis'] = RedisConnection
+    RedisConnection.logger = logger.getChild("redis")
+    app['logger'] = logger.getChild("route")
+    StatsdConnection.logger = logger.getChild("statsd")
+    app['stats'] = StatsdConnection
+
+    # Add our config
+    app['config'] = config
+
+    loop = app.loop
+
+    # Connect the database pool
+    if app['config'].get('database', {}).get('enabled', False):
+        db_connect_task = start_database_pool(app['config'])
+        loop.run_until_complete(db_connect_task)
+
+    # Connect the redis pool
+    if app['config'].get('redis', {}).get('enabled', False):
+        re_connect = start_redis_pool(app['config'])
+        loop.run_until_complete(re_connect)
+
+    # Add our bots
+    app['bots'] = {}
+    for index, (bot_name, bot_config_location) in enumerate(config.get('discord_bot_configs', dict()).items()):
+        bot = Bot(f"./config/{bot_config_location}")
+        app['bots'][bot_name] = bot
+        if index == 0:
+            set_default_log_levels(bot, args)
+        try:
+            loop.run_until_complete(bot.login())
+            bot.load_all_extensions()
+        except Exception as e:
+            logger.error(f"Failed to start bot {bot_name}")
+            logger.error(e)
+            exit(1)
+
+    # Start the HTTP server
+    logger.info("Creating webserver...")
+    application = AppRunner(app)
+    loop.run_until_complete(application.setup())
+    webserver = TCPSite(application, host=args.host, port=args.port)
+
+    # Start the webserver
+    loop.run_until_complete(webserver.start())
+    logger.info(f"Server started - http://{args.host}:{args.port}/")
+
+    # This is the forever loop
+    try:
+        logger.info("Running webserver")
+        loop.run_forever()
+    except KeyboardInterrupt:
+        pass
+
+    # We're now done running the bot, time to clean up and close
+    loop.run_until_complete(application.cleanup())
+    if config.get('database', {}).get('enabled', False):
+        logger.info("Closing database pool")
+        try:
+            loop.run_until_complete(asyncio.wait_for(DatabaseConnection.pool.close(), timeout=30.0))
+        except asyncio.TimeoutError:
+            logger.error("Couldn't gracefully close the database connection pool within 30 seconds")
+    if config.get('redis', {}).get('enabled', False):
+        logger.info("Closing redis pool")
+        RedisConnection.pool.close()
+
+    logger.info("Closing asyncio loop")
+    loop.stop()
+    loop.close()
